#' @importFrom Rlibeemd emd_num_imfs emd
#' @importFrom nnfor elm
#' @importFrom forecast forecast
#' @importFrom utils head tail
#' @importFrom graphics plot
#' @importFrom stats as.ts ts
#' @export
#'

emdELM <- function(xt, stepahead=10,
                   s.num=4L, num.sift=50L){
  data<-ts(xt)
  n.IMF <- emd_num_imfs(length(data))
  AllIMF <- emd(data, num_imfs = n.IMF, S_number = s.num, num_siftings = num.sift)
  data_trn <- ts(head(data, round(length(data) - stepahead)))
  data_test <- ts(tail(data, stepahead))
  IMF_trn <- AllIMF[-c(((length(data)-stepahead)+1):length(data)),]
  Fcast_AllIMF <- NULL
  for (IMF in 1:ncol(IMF_trn)) {
    IndIMF <- NULL
    IndIMF <- IMF_trn[ ,IMF]
    emdELMFit <- nnfor::elm(as.ts(IndIMF), keep = NULL, difforder = NULL, outplot = c(
      FALSE), sel.lag = c(FALSE), direct = c(FALSE),
      allow.det.season = c(FALSE))
    emdELM_fcast=forecast::forecast(emdELMFit, h=stepahead)
    emdELM_fcast_Mean=emdELM_fcast$mean
    Fcast_AllIMF <- cbind(Fcast_AllIMF, as.matrix(emdELM_fcast_Mean))
  }
  FinalemdELM_fcast <- ts(rowSums(Fcast_AllIMF, na.rm = T))
  MAE_emdELM=mean(abs(data_test - FinalemdELM_fcast))
  MAPE_emdELM=mean(abs(data_test - FinalemdELM_fcast)/data_test)
  rmse_emdELM=sqrt(mean((data_test - FinalemdELM_fcast)^2))
  Plot_IMFs <- AllIMF
  AllIMF_plots <- plot(Plot_IMFs)
  return(list(TotalIMF = n.IMF, AllIMF=AllIMF, data_test=data_test, AllIMF_forecast=Fcast_AllIMF,
              FinalemdELM_forecast=FinalemdELM_fcast, MAE_emdELM=MAE_emdELM,
              MAPE_emdELM=MAPE_emdELM, rmse_emdELM=rmse_emdELM,
              AllIMF_plots=AllIMF_plots))
}
